#! /bin/bash

# Author: Francesco Visin
# 
# This script will create a 'package_filename'.launch and a launcher file. The first is a standard ros launch file, the second one is another bash script that will setup the environment and then perform the operations necessary to launch the package in gazebo.
# NOTE: The script has to be copied insied the package folder before being executed.
# Please set the following variable to the name of the package, before executing this script
package_filename="gazebo_control_model"


# creating launch file
echo \
"<launch>

  <arg name=\"paused\" default=\"false\"/>
  <arg name=\"use_sim_time\" default=\"true\"/>
  <arg name=\"gui\" default=\"true\"/>
  <arg name=\"throttled\" default=\"false\"/>

  <!-- set use_sim_time flag -->
  <group if=\"\$(arg use_sim_time)\">
    <param name=\"/use_sim_time\" value=\"true\" />
  </group>


  <!-- start empty world -->
  <group if=\"\$(arg paused)\">
    <group if=\"\$(arg throttled)\">
      <node name=\"gazebo\" pkg=\"gazebo\" type=\"gazebo\" args=\"-u `pwd`/`echo $package_filename`.world\" respawn=\"false\" output=\"screen\"/>
    </group>
    <group unless=\"\$(arg throttled)\">
      <node name=\"gazebo\" pkg=\"gazebo\" type=\"gazebo\" args=\"-u `pwd`/`echo $package_filename`.world\" respawn=\"false\" output=\"screen\"/>
    </group>
  </group>
  <group unless=\"\$(arg paused)\">
    <group if=\"\$(arg throttled)\">
      <node name=\"gazebo\" pkg=\"gazebo\" type=\"gazebo\" args=\"`pwd`/`echo $package_filename`.world\" respawn=\"false\" output=\"screen\"/>
    </group>
    <group unless=\"\$(arg throttled)\">
      <node name=\"gazebo\" pkg=\"gazebo\" type=\"gazebo\" args=\"`pwd`/`echo $package_filename`.world\" respawn=\"false\" output=\"screen\"/>
    </group>
  </group>

  <!-- start gui -->
  <group if=\"\$(arg gui)\">
    <node name=\"gazebo_gui\" pkg=\"gazebo\" type=\"gui\" respawn=\"false\" output=\"screen\"/>
  </group>

</launch>" \
 > `echo $package_filename`.launch
 # make it executable
 chmod ugoa+x `echo $package_filename`.launch



# creating launcher
echo \
"#! /bin/bash

source /opt/ros/groovy/setup.bash
export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH
export GAZEBO_PLUGIN_PATH=\`pwd\`/build:\$GAZEBO_PLUGIN_PATH

gnome-terminal \\
--tab --title='ROSCORE' -e \"bash -c \\\"echo 'roscore'; export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH; roscore; exec bash\\\"\" \\
\\
--tab --title='GAZEBO' -e \"bash -c \\\"echo 'rosrun gazebo gazebo `echo $package_filename`.world'; echo 'waiting for roscore...'; sleep 4; export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH; echo \$ROS_PACKAGE_PATH; export GAZEBO_PLUGIN_PATH=\`pwd\`/build:\$GAZEBO_PLUGIN_PATH; roslaunch `echo $package_filename`.launch ; exec bash\\\"\"

exit" > launcher
# make it executable
chmod ugoa+x launcher